@@ -22,16 +22,15 @@
 
 using namespace NotificationManager;
 
-JobControl::JobControl(QObject* parent, Job *job)
-    : Plasma::Service(parent),
-      m_job(job)
+JobControl::JobControl(QObject *parent, Job *job)
+    : Plasma::Service(parent)
+    , m_job(job)
 {
     setName(QStringLiteral("applicationjobs"));
     setDestination(KuiserverEngine::sourceName(job));
 }
 
-Plasma::ServiceJob* JobControl::createJob(const QString& operation,
-                                          QMap<QString,QVariant>& parameters)
+Plasma::ServiceJob *JobControl::createJob(const QString &operation, QMap<QString, QVariant> &parameters)
 {
     return new JobAction(m_job, operation, parameters, this);
 }
