@@ -21,16 +21,17 @@
 
 #include "powermanagementengine.h"
 
-//solid specific includes
-#include <solid/devicenotifier.h>
+// kde-workspace/libs
+#include <sessionmanagement.h>
+
+// solid specific includes
 #include <solid/device.h>
 #include <solid/deviceinterface.h>
-#include <solid/battery.h>
-#include <solid/powermanagement.h>
+#include <solid/devicenotifier.h>
 
-#include <klocalizedstring.h>
 #include <KAuthorized>
 #include <KIdleTime>
+#include <klocalizedstring.h>
 
 #include <QDebug>
 
@@ -38,20 +39,21 @@
 #include <QDBusError>
 #include <QDBusInterface>
 #include <QDBusMetaType>
-#include <QDBusReply>
 #include <QDBusPendingCallWatcher>
+#include <QDBusReply>
 
-#include <Plasma/DataContainer>
 #include "powermanagementservice.h"
+#include <Plasma/DataContainer>
 
 static const char SOLID_POWERMANAGEMENT_SERVICE[] = "org.kde.Solid.PowerManagement";
 
 Q_DECLARE_METATYPE(QList<InhibitionInfo>)
 Q_DECLARE_METATYPE(InhibitionInfo)
 
-PowermanagementEngine::PowermanagementEngine(QObject* parent, const QVariantList& args)
-        : Plasma::DataEngine(parent, args)
-        , m_sources(basicSourceNames())
+PowermanagementEngine::PowermanagementEngine(QObject *parent, const QVariantList &args)
+    : Plasma::DataEngine(parent, args)
+    , m_sources(basicSourceNames())
+    , m_session(new SessionManagement(this))
 {
     Q_UNUSED(args)
     qDBusRegisterMetaType<QList<InhibitionInfo>>();
@@ -60,20 +62,20 @@ PowermanagementEngine::PowermanagementEngine(QObject* parent, const QVariantList
 }
 
 PowermanagementEngine::~PowermanagementEngine()
-{}
+{
+}
 
 void PowermanagementEngine::init()
 {
-    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded,
-            this,                              &PowermanagementEngine::deviceAdded);
-    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved,
-            this,                              &PowermanagementEngine::deviceRemoved);
+    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded, this, &PowermanagementEngine::deviceAdded);
+    connect(Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved, this, &PowermanagementEngine::deviceRemoved);
 
     if (QDBusConnection::sessionBus().interface()->isServiceRegistered(SOLID_POWERMANAGEMENT_SERVICE)) {
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
-                                                   QStringLiteral("brightnessChanged"), this,
+                                                   QStringLiteral("brightnessChanged"),
+                                                   this,
                                                    SLOT(screenBrightnessChanged(int)))) {
             qDebug() << "error connecting to Brightness changes via dbus";
         }
@@ -81,7 +83,8 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
-                                                   QStringLiteral("brightnessMaxChanged"), this,
+                                                   QStringLiteral("brightnessMaxChanged"),
+                                                   this,
                                                    SLOT(maximumScreenBrightnessChanged(int)))) {
             qDebug() << "error connecting to max brightness changes via dbus";
         }
@@ -89,7 +92,8 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/Actions/KeyboardBrightnessControl"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl"),
-                                                   QStringLiteral("keyboardBrightnessChanged"), this,
+                                                   QStringLiteral("keyboardBrightnessChanged"),
+                                                   this,
                                                    SLOT(keyboardBrightnessChanged(int)))) {
             qDebug() << "error connecting to Keyboard Brightness changes via dbus";
         }
@@ -97,7 +101,8 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/Actions/KeyboardBrightnessControl"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl"),
-                                                   QStringLiteral("keyboardBrightnessMaxChanged"), this,
+                                                   QStringLiteral("keyboardBrightnessMaxChanged"),
+                                                   this,
                                                    SLOT(maximumKeyboardBrightnessChanged(int)))) {
             qDebug() << "error connecting to max keyboard Brightness changes via dbus";
         }
@@ -105,7 +110,8 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/Actions/HandleButtonEvents"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.Actions.HandleButtonEvents"),
-                                                   QStringLiteral("triggersLidActionChanged"), this,
+                                                   QStringLiteral("triggersLidActionChanged"),
+                                                   this,
                                                    SLOT(triggersLidActionChanged(bool)))) {
             qDebug() << "error connecting to lid action trigger changes via dbus";
         }
@@ -113,15 +119,17 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement/PolicyAgent"),
                                                    QStringLiteral("org.kde.Solid.PowerManagement.PolicyAgent"),
-                                                   QStringLiteral("InhibitionsChanged"), this,
-                                                   SLOT(inhibitionsChanged(QList<InhibitionInfo>,QStringList)))) {
+                                                   QStringLiteral("InhibitionsChanged"),
+                                                   this,
+                                                   SLOT(inhibitionsChanged(QList<InhibitionInfo>, QStringList)))) {
             qDebug() << "error connecting to inhibition changes via dbus";
         }
 
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement"),
                                                    SOLID_POWERMANAGEMENT_SERVICE,
-                                                   QStringLiteral("batteryRemainingTimeChanged"), this,
+                                                   QStringLiteral("batteryRemainingTimeChanged"),
+                                                   this,
                                                    SLOT(batteryRemainingTimeChanged(qulonglong)))) {
             qDebug() << "error connecting to remaining time changes";
         }
@@ -129,7 +137,8 @@ void PowermanagementEngine::init()
         if (!QDBusConnection::sessionBus().connect(SOLID_POWERMANAGEMENT_SERVICE,
                                                    QStringLiteral("/org/kde/Solid/PowerManagement"),
                                                    SOLID_POWERMANAGEMENT_SERVICE,
-                                                   QStringLiteral("chargeStopThresholdChanged"), this,
+                                                   QStringLiteral("chargeStopThresholdChanged"),
+                                                   this,
                                                    SLOT(chargeStopThresholdChanged(int)))) {
             qDebug() << "error connecting to charge stop threshold changes via dbus";
         }
@@ -139,7 +148,8 @@ void PowermanagementEngine::init()
 QStringList PowermanagementEngine::basicSourceNames() const
 {
     QStringList sources;
-    sources << QStringLiteral("Battery") << QStringLiteral("AC Adapter") << QStringLiteral("Sleep States") << QStringLiteral("PowerDevil") << QStringLiteral("Inhibitions");
+    sources << QStringLiteral("Battery") << QStringLiteral("AC Adapter") << QStringLiteral("Sleep States") << QStringLiteral("PowerDevil")
+            << QStringLiteral("Inhibitions");
     return sources;
 }
 
@@ -164,21 +174,17 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
         QStringList batterySources;
 
         foreach (const Solid::Device &deviceBattery, listBattery) {
-            const Solid::Battery* battery = deviceBattery.as<Solid::Battery>();
+            const Solid::Battery *battery = deviceBattery.as<Solid::Battery>();
 
             const QString source = QStringLiteral("Battery%1").arg(index++);
 
             batterySources << source;
             m_batterySources[deviceBattery.udi()] = source;
 
-            connect(battery, &Solid::Battery::chargeStateChanged, this,
-                    &PowermanagementEngine::updateBatteryChargeState);
-            connect(battery, &Solid::Battery::chargePercentChanged, this,
-                    &PowermanagementEngine::updateBatteryChargePercent);
-            connect(battery, &Solid::Battery::energyChanged,
-                    this, &PowermanagementEngine::updateBatteryEnergy);
-            connect(battery, &Solid::Battery::presentStateChanged, this,
-                    &PowermanagementEngine::updateBatteryPresentState);
+            connect(battery, &Solid::Battery::chargeStateChanged, this, &PowermanagementEngine::updateBatteryChargeState);
+            connect(battery, &Solid::Battery::chargePercentChanged, this, &PowermanagementEngine::updateBatteryChargePercent);
+            connect(battery, &Solid::Battery::energyChanged, this, &PowermanagementEngine::updateBatteryEnergy);
+            connect(battery, &Solid::Battery::presentStateChanged, this, &PowermanagementEngine::updateBatteryPresentState);
 
             // Set initial values
             updateBatteryChargeState(battery->chargeState(), deviceBattery.udi());
@@ -230,22 +236,31 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
 
         m_sources = basicSourceNames() + batterySources;
     } else if (name == QLatin1String("AC Adapter")) {
-        connect(Solid::PowerManagement::notifier(), &Solid::PowerManagement::Notifier::appShouldConserveResourcesChanged,
-                this, &PowermanagementEngine::updateAcPlugState);
-        updateAcPlugState(Solid::PowerManagement::appShouldConserveResources());
+        QDBusConnection::sessionBus().connect(QStringLiteral("org.freedesktop.PowerManagement"),
+                                              QStringLiteral("/org/freedesktop/PowerManagement"),
+                                              QStringLiteral("org.freedesktop.PowerManagement"),
+                                              QStringLiteral("PowerSaveStatusChanged"),
+                                              this,
+                                              SLOT(updateAcPlugState(bool)));
+
+        QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.PowerManagement"),
+                                                          QStringLiteral("/org/freedesktop/PowerManagement"),
+                                                          QStringLiteral("org.freedesktop.PowerManagement"),
+                                                          QStringLiteral("GetPowerSaveStatus"));
+        QDBusReply<bool> reply = QDBusConnection::sessionBus().call(msg);
+        updateAcPlugState(reply.isValid() ? reply.value() : false);
     } else if (name == QLatin1String("Sleep States")) {
-        const QSet<Solid::PowerManagement::SleepState> sleepstates = Solid::PowerManagement::supportedSleepStates();
-        setData(QStringLiteral("Sleep States"), QStringLiteral("Standby"), sleepstates.contains(Solid::PowerManagement::StandbyState));
-        setData(QStringLiteral("Sleep States"), QStringLiteral("Suspend"), sleepstates.contains(Solid::PowerManagement::SuspendState));
-        setData(QStringLiteral("Sleep States"), QStringLiteral("Hibernate"), sleepstates.contains(Solid::PowerManagement::HibernateState));
-        setData(QStringLiteral("Sleep States"), QStringLiteral("HybridSuspend"), sleepstates.contains(Solid::PowerManagement::HybridSuspendState));
-        setData(QStringLiteral("Sleep States"), QStringLiteral("LockScreen"), KAuthorized::authorizeAction(QStringLiteral("lock_screen")));
-        setData(QStringLiteral("Sleep States"), QStringLiteral("Logout"), KAuthorized::authorize(QStringLiteral("logout")));
+        setData(QStringLiteral("Sleep States"), QStringLiteral("Standby"), m_session->canSuspend());
+        setData(QStringLiteral("Sleep States"), QStringLiteral("Suspend"), m_session->canSuspend());
+        setData(QStringLiteral("Sleep States"), QStringLiteral("Hibernate"), m_session->canHibernate());
+        setData(QStringLiteral("Sleep States"), QStringLiteral("HybridSuspend"), m_session->canHybridSuspend());
+        setData(QStringLiteral("Sleep States"), QStringLiteral("LockScreen"), m_session->canLock());
+        setData(QStringLiteral("Sleep States"), QStringLiteral("Logout"), m_session->canLogout());
     } else if (name == QLatin1String("PowerDevil")) {
         QDBusMessage screenMsg = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
-                                                              QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
-                                                              QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
-                                                              QStringLiteral("brightness"));
+                                                                QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
+                                                                QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
+                                                                QStringLiteral("brightness"));
         QDBusPendingReply<int> screenReply = QDBusConnection::sessionBus().asyncCall(screenMsg);
         QDBusPendingCallWatcher *screenWatcher = new QDBusPendingCallWatcher(screenReply, this);
         QObject::connect(screenWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
@@ -257,9 +272,9 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
         });
 
         QDBusMessage maxScreenMsg = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
-                                                                  QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
-                                                                  QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
-                                                                  QStringLiteral("brightnessMax"));
+                                                                   QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
+                                                                   QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
+                                                                   QStringLiteral("brightnessMax"));
         QDBusPendingReply<int> maxScreenReply = QDBusConnection::sessionBus().asyncCall(maxScreenMsg);
         QDBusPendingCallWatcher *maxScreenWatcher = new QDBusPendingCallWatcher(maxScreenReply, this);
         QObject::connect(maxScreenWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
@@ -271,9 +286,9 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
         });
 
         QDBusMessage keyboardMsg = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
-                                                                QStringLiteral("/org/kde/Solid/PowerManagement/Actions/KeyboardBrightnessControl"),
-                                                                QStringLiteral("org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl"),
-                                                                QStringLiteral("keyboardBrightness"));
+                                                                  QStringLiteral("/org/kde/Solid/PowerManagement/Actions/KeyboardBrightnessControl"),
+                                                                  QStringLiteral("org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl"),
+                                                                  QStringLiteral("keyboardBrightness"));
         QDBusPendingReply<int> keyboardReply = QDBusConnection::sessionBus().asyncCall(keyboardMsg);
         QDBusPendingCallWatcher *keyboardWatcher = new QDBusPendingCallWatcher(keyboardReply, this);
         QObject::connect(keyboardWatcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
@@ -298,7 +313,6 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
             watcher->deleteLater();
         });
 
-
         QDBusMessage lidIsPresentMsg = QDBusMessage::createMethodCall(SOLID_POWERMANAGEMENT_SERVICE,
                                                                       QStringLiteral("/org/kde/Solid/PowerManagement"),
                                                                       SOLID_POWERMANAGEMENT_SERVICE,
@@ -345,7 +359,7 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
             }
         });
 
-    //any info concerning lock screen/screensaver goes here
+        // any info concerning lock screen/screensaver goes here
     } else if (name == QLatin1String("UserActivity")) {
         setData(QStringLiteral("UserActivity"), QStringLiteral("IdleTime"), KIdleTime::instance()->idleTime());
     } else {
@@ -355,41 +369,41 @@ bool PowermanagementEngine::sourceRequestEvent(const QString &name)
     return true;
 }
 
-QString PowermanagementEngine::batteryType(const Solid::Battery* battery) const
+QString PowermanagementEngine::batteryType(const Solid::Battery *battery) const
 {
-  switch(battery->type()) {
-      case Solid::Battery::PrimaryBattery:
-          return QStringLiteral("Battery");
-          break;
-      case Solid::Battery::UpsBattery:
-          return QStringLiteral("Ups");
-          break;
-      case Solid::Battery::MonitorBattery:
-          return QStringLiteral("Monitor");
-          break;
-      case Solid::Battery::MouseBattery:
-          return QStringLiteral("Mouse");
-          break;
-      case Solid::Battery::KeyboardBattery:
-          return QStringLiteral("Keyboard");
-          break;
-      case Solid::Battery::PdaBattery:
-          return QStringLiteral("Pda");
-          break;
-      case Solid::Battery::PhoneBattery:
-          return QStringLiteral("Phone");
-          break;
-      case Solid::Battery::GamingInputBattery:
-          return QStringLiteral("GamingInput");
-          break;
-      case Solid::Battery::BluetoothBattery:
-          return QStringLiteral("Bluetooth");
-          break;
-      default:
-          return QStringLiteral("Unknown");
-  }
+    switch (battery->type()) {
+    case Solid::Battery::PrimaryBattery:
+        return QStringLiteral("Battery");
+        break;
+    case Solid::Battery::UpsBattery:
+        return QStringLiteral("Ups");
+        break;
+    case Solid::Battery::MonitorBattery:
+        return QStringLiteral("Monitor");
+        break;
+    case Solid::Battery::MouseBattery:
+        return QStringLiteral("Mouse");
+        break;
+    case Solid::Battery::KeyboardBattery:
+        return QStringLiteral("Keyboard");
+        break;
+    case Solid::Battery::PdaBattery:
+        return QStringLiteral("Pda");
+        break;
+    case Solid::Battery::PhoneBattery:
+        return QStringLiteral("Phone");
+        break;
+    case Solid::Battery::GamingInputBattery:
+        return QStringLiteral("GamingInput");
+        break;
+    case Solid::Battery::BluetoothBattery:
+        return QStringLiteral("Bluetooth");
+        break;
+    default:
+        return QStringLiteral("Unknown");
+    }
 
-  return QStringLiteral("Unknown");
+    return QStringLiteral("Unknown");
 }
 
 bool PowermanagementEngine::updateSourceEvent(const QString &source)
@@ -401,7 +415,7 @@ bool PowermanagementEngine::updateSourceEvent(const QString &source)
     return Plasma::DataEngine::updateSourceEvent(source);
 }
 
-Plasma::Service* PowermanagementEngine::serviceForSource(const QString &source)
+Plasma::Service *PowermanagementEngine::serviceForSource(const QString &source)
 {
     if (source == QLatin1String("PowerDevil")) {
         return new PowerManagementService(this);
@@ -426,20 +440,20 @@ QString PowermanagementEngine::batteryStateToString(int newState) const
     return state;
 }
 
-void PowermanagementEngine::updateBatteryChargeState(int newState, const QString& udi)
+void PowermanagementEngine::updateBatteryChargeState(int newState, const QString &udi)
 {
     const QString source = m_batterySources[udi];
     setData(source, QStringLiteral("State"), batteryStateToString(newState));
     updateOverallBattery();
 }
 
-void PowermanagementEngine::updateBatteryPresentState(bool newState, const QString& udi)
+void PowermanagementEngine::updateBatteryPresentState(bool newState, const QString &udi)
 {
     const QString source = m_batterySources[udi];
     setData(source, QStringLiteral("Plugged in"), newState); // FIXME This needs to be renamed and Battery Monitor adjusted
 }
 
-void PowermanagementEngine::updateBatteryChargePercent(int newValue, const QString& udi)
+void PowermanagementEngine::updateBatteryChargePercent(int newValue, const QString &udi)
 {
     const QString source = m_batterySources[udi];
     setData(source, QStringLiteral("Percent"), newValue);
@@ -452,7 +466,7 @@ void PowermanagementEngine::updateBatteryEnergy(double newValue, const QString &
     setData(source, QStringLiteral("Energy"), newValue);
 }
 
-void PowermanagementEngine::updateBatteryPowerSupplyState(bool newState, const QString& udi)
+void PowermanagementEngine::updateBatteryPowerSupplyState(bool newState, const QString &udi)
 {
     const QString source = m_batterySources[udi];
     setData(source, QStringLiteral("Is Power Supply"), newState);
@@ -468,8 +482,8 @@ void PowermanagementEngine::updateBatteryNames()
             const QString batteryProduct = batteryDataContainer->data()[QStringLiteral("Product")].toString();
 
             // Don't show battery name for primary power supply batteries. They usually have cryptic serial number names.
-            const bool showBatteryName = batteryDataContainer->data()[QStringLiteral("Type")].toString() != QLatin1String("Battery") ||
-                                         !batteryDataContainer->data()[QStringLiteral("Is Power Supply")].toBool();
+            const bool showBatteryName = batteryDataContainer->data()[QStringLiteral("Type")].toString() != QLatin1String("Battery")
+                || !batteryDataContainer->data()[QStringLiteral("Is Power Supply")].toBool();
 
             if (!batteryProduct.isEmpty() && batteryProduct != QLatin1String("Unknown Battery") && showBatteryName) {
                 if (!batteryVendor.isEmpty()) {
@@ -503,7 +517,7 @@ void PowermanagementEngine::updateOverallBattery()
     int count = 0;
 
     foreach (const Solid::Device &deviceBattery, listBattery) {
-        const Solid::Battery* battery = deviceBattery.as<Solid::Battery>();
+        const Solid::Battery *battery = deviceBattery.as<Solid::Battery>();
 
         if (battery && battery->isPowerSupply()) {
             hasCumulative = true;
@@ -553,11 +567,11 @@ void PowermanagementEngine::updateAcPlugState(bool onBattery)
     setData(QStringLiteral("AC Adapter"), QStringLiteral("Plugged in"), !onBattery);
 }
 
-void PowermanagementEngine::deviceRemoved(const QString& udi)
+void PowermanagementEngine::deviceRemoved(const QString &udi)
 {
     if (m_batterySources.contains(udi)) {
         Solid::Device device(udi);
-        Solid::Battery* battery = device.as<Solid::Battery>();
+        Solid::Battery *battery = device.as<Solid::Battery>();
         if (battery)
             battery->disconnect();
 
@@ -574,11 +588,11 @@ void PowermanagementEngine::deviceRemoved(const QString& udi)
     }
 }
 
-void PowermanagementEngine::deviceAdded(const QString& udi)
+void PowermanagementEngine::deviceAdded(const QString &udi)
 {
     Solid::Device device(udi);
     if (device.isValid()) {
-        const Solid::Battery* battery = device.as<Solid::Battery>();
+        const Solid::Battery *battery = device.as<Solid::Battery>();
 
         if (battery) {
             int index = 0;
@@ -591,16 +605,11 @@ void PowermanagementEngine::deviceAdded(const QString& udi)
             sourceNames << source;
             m_batterySources[device.udi()] = source;
 
-            connect(battery, &Solid::Battery::chargeStateChanged, this,
-                    &PowermanagementEngine::updateBatteryChargeState);
-            connect(battery, &Solid::Battery::chargePercentChanged, this,
-                    &PowermanagementEngine::updateBatteryChargePercent);
-            connect(battery, &Solid::Battery::energyChanged,
-                    this, &PowermanagementEngine::updateBatteryEnergy);
-            connect(battery, &Solid::Battery::presentStateChanged, this,
-                    &PowermanagementEngine::updateBatteryPresentState);
-            connect(battery, &Solid::Battery::powerSupplyStateChanged, this,
-                    &PowermanagementEngine::updateBatteryPowerSupplyState);
+            connect(battery, &Solid::Battery::chargeStateChanged, this, &PowermanagementEngine::updateBatteryChargeState);
+            connect(battery, &Solid::Battery::chargePercentChanged, this, &PowermanagementEngine::updateBatteryChargePercent);
+            connect(battery, &Solid::Battery::energyChanged, this, &PowermanagementEngine::updateBatteryEnergy);
+            connect(battery, &Solid::Battery::presentStateChanged, this, &PowermanagementEngine::updateBatteryPresentState);
+            connect(battery, &Solid::Battery::powerSupplyStateChanged, this, &PowermanagementEngine::updateBatteryPowerSupplyState);
 
             // Set initial values
             updateBatteryChargeState(battery->chargeState(), device.udi());
@@ -625,7 +634,7 @@ void PowermanagementEngine::deviceAdded(const QString& udi)
 
 void PowermanagementEngine::batteryRemainingTimeChanged(qulonglong time)
 {
-    //qDebug() << "Remaining time 2:" << time;
+    // qDebug() << "Remaining time 2:" << time;
     setData(QStringLiteral("Battery"), QStringLiteral("Remaining msec"), time);
 }
 
@@ -670,11 +679,9 @@ void PowermanagementEngine::inhibitionsChanged(const QList<InhibitionInfo> &adde
 
         populateApplicationData(name, &prettyName, &icon);
 
-        setData(QStringLiteral("Inhibitions"), name, QVariantMap{
-            {QStringLiteral("Name"), prettyName},
-            {QStringLiteral("Icon"), icon},
-            {QStringLiteral("Reason"), reason}
-        });
+        setData(QStringLiteral("Inhibitions"),
+                name,
+                QVariantMap{{QStringLiteral("Name"), prettyName}, {QStringLiteral("Icon"), icon}, {QStringLiteral("Reason"), reason}});
     }
 }
 
