@@ -570,10 +570,10 @@ void KDisplayManager::shutdown(KWorkSpace::ShutdownType shutdownType,
         cmd.append(shutdownType == KWorkSpace::ShutdownTypeReboot ? "reboot\t" : "halt\t");
         if (!bootOption.isEmpty())
             cmd.append("=").append(bootOption.toLocal8Bit()).append("\t");
-        cmd.append(shutdownMode == KWorkSpace::ShutdownModeInteractive
-                       ? "ask\n"
+        cmd.append(shutdownMode == KWorkSpace::ShutdownModeInteractive    ? "ask\n"
                        : shutdownMode == KWorkSpace::ShutdownModeForceNow ? "forcenow\n"
-                                                                          : shutdownMode == KWorkSpace::ShutdownModeTryNow ? "trynow\n" : "schedule\n");
+                       : shutdownMode == KWorkSpace::ShutdownModeTryNow   ? "trynow\n"
+                                                                          : "schedule\n");
     }
     exec(cmd.data());
 }
@@ -782,10 +782,13 @@ void KDisplayManager::sess2Str2(const SessEnt &se, QString &user, QString &loc)
         user = i18nc("user: ...", "%1: TTY login", se.user);
         loc = se.vt ? QStringLiteral("vt%1").arg(se.vt) : se.display;
     } else {
+        // clang-format off
         user = se.user.isEmpty() ? se.session.isEmpty()
-                ? i18nc("... location (TTY or X display)", "Unused")
-                : se.session == QLatin1String("<remote>") ? i18n("X login on remote host") : i18nc("... host", "X login on %1", se.session)
-                                 : se.session == QLatin1String("<unknown>") ? se.user : i18nc("user: session type", "%1: %2", se.user, se.session);
+                                 ? i18nc("... location (TTY or X display)", "Unused") : se.session == QLatin1String("<remote>") 
+                                 ? i18n("X login on remote host")                     : i18nc("... host", "X login on %1", se.session) 
+                                                                                      : se.session == QLatin1String("<unknown>") 
+                                 ? se.user                                            : i18nc("user: session type", "%1: %2", se.user, se.session);
+        // clang-format on
         loc = se.vt ? QStringLiteral("%1, vt%2").arg(se.display).arg(se.vt) : se.display;
     }
 }
